@@ -45,13 +45,27 @@
 #include <gtk/gtkliststore.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeview.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtkcellrenderertoggle.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkstock.h>
+
+#include <libgnomeui/gnome-file-entry.h>
+#include <libgnomeui/gnome-color-picker.h>
+
+#include <gtkhtml/gtkhtml.h>
 
 #include "widgets/misc/e-charset-picker.h"
+#include "widgets/misc/e-error.h"
+
+#include <e-util/e-icon-factory.h>
 
 #include "mail-config.h"
-
-#include "art/mark.xpm"
-
+#include "mail-signature-editor.h"
 
 #define d(x)
 
@@ -101,9 +115,7 @@ em_composer_prefs_class_init (EMComposerPrefsClass *klass)
 static void
 em_composer_prefs_init (EMComposerPrefs *prefs)
 {
-	prefs->enabled_pixbuf = gdk_pixbuf_new_from_xpm_data ((const char **) mark_xpm);
-	gdk_pixbuf_render_pixmap_and_mask (prefs->enabled_pixbuf, &prefs->mark_pixmap, &prefs->mark_bitmap, 128);
-	
+	prefs->enabled_pixbuf = e_icon_factory_get_icon ("stock_mark", E_ICON_SIZE_MENU);
 	prefs->sig_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 }
 
@@ -120,8 +132,6 @@ em_composer_prefs_finalise (GObject *obj)
 	
 	g_object_unref (prefs->gui);
 	g_object_unref (prefs->enabled_pixbuf);
-	gdk_pixmap_unref (prefs->mark_pixmap);
-	g_object_unref (prefs->mark_bitmap);
 	
 	g_hash_table_foreach (prefs->sig_hash, (GHFunc) row_free, NULL);
 	g_hash_table_destroy (prefs->sig_hash);
@@ -316,11 +326,11 @@ sig_edit_cb (GtkWidget *widget, EMComposerPrefs *prefs)
 }
 
 void
-em_composer_prefs_new_signature (GtkWindow *parent, gboolean html, const char *script)
+em_composer_prefs_new_signature (GtkWindow *parent, gboolean html)
 {
 	ESignature *sig;
 	
-	sig = mail_config_signature_new (script, script ? TRUE : FALSE, html);
+	sig = mail_config_signature_new (NULL, FALSE, html);
 	mail_signature_editor (sig, parent, TRUE);
 }
 
@@ -352,16 +362,16 @@ sig_add_cb (GtkWidget *widget, EMComposerPrefs *prefs)
 	parent = gtk_widget_get_toplevel ((GtkWidget *) prefs);
 	parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
 	
-	em_composer_prefs_new_signature ((GtkWindow *) parent, send_html, NULL);
+	em_composer_prefs_new_signature ((GtkWindow *) parent, send_html);
 }
 
 static void
 sig_add_script_response (GtkWidget *widget, int button, EMComposerPrefs *prefs)
 {
-	const char *name;
-	char *script;
-	GtkWidget *dialog;
+	char *script, **argv = NULL;
 	GtkWidget *entry;
+	const char *name;
+	int argc;
 	
 	if (button == GTK_RESPONSE_ACCEPT) {
 		entry = glade_xml_get_widget (prefs->sig_script_gui, "fileentry_add_script_script");
@@ -369,40 +379,36 @@ sig_add_script_response (GtkWidget *widget, int button, EMComposerPrefs *prefs)
 		
 		entry = glade_xml_get_widget (prefs->sig_script_gui, "entry_add_script_name");
 		name = gtk_entry_get_text (GTK_ENTRY (entry));
-		if (script && *script) {
+		if (script && *script && g_shell_parse_argv (script, &argc, &argv, NULL)) {
 			struct stat st;
 			
-			if (stat (script, &st) && S_ISREG (st.st_mode) && access (script, X_OK) == 0) {
-				GtkWidget *parent;
+			if (stat (argv[0], &st) == 0 && S_ISREG (st.st_mode) && access (argv[0], X_OK) == 0) {
 				ESignature *sig;
 				
-				parent = gtk_widget_get_toplevel ((GtkWidget *) prefs);
-				parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
-				
 				if ((sig = g_object_get_data ((GObject *) entry, "sig"))) {
 					/* we're just editing an existing signature script */
 					g_free (sig->name);
 					sig->name = g_strdup (name);
 					e_signature_list_change (mail_config_get_signatures (), sig);
 				} else {
-					em_composer_prefs_new_signature ((GtkWindow *) parent, TRUE, script);
+					sig = mail_config_signature_new (script, TRUE, TRUE);
+					sig->name = g_strdup (name);
+					
+					e_signature_list_add (mail_config_get_signatures (), sig);
+					g_object_unref (sig);
 				}
 				
 				gtk_widget_hide (prefs->sig_script_dialog);
-				g_free(script);
+				g_strfreev (argv);
+				g_free (script);
 				
 				return;
 			}
 		}
 		
-		g_free(script);
-		dialog = gtk_message_dialog_new (GTK_WINDOW (prefs->sig_script_dialog),
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 "%s", _("You must specify a valid script name."));
-		
-		gtk_dialog_run ((GtkDialog *) dialog);
-		gtk_widget_destroy (dialog);
+		e_error_run((GtkWindow *)prefs->sig_script_dialog, "mail:signature-notscript", argv ? argv[0] : script, NULL);
+		g_strfreev (argv);
+		g_free (script);
 		return;
 	}
 	
@@ -434,7 +440,8 @@ sig_selection_changed (GtkTreeSelection *selection, EMComposerPrefs *prefs)
 	if (state) {
 		gtk_tree_model_get (model, &iter, 1, &sig, -1);
 		sig_load_preview (prefs, sig);
-	}
+	} else
+		sig_load_preview (prefs, NULL);
 	
 	gtk_widget_set_sensitive ((GtkWidget *) prefs->sig_delete, state);
 	gtk_widget_set_sensitive ((GtkWidget *) prefs->sig_edit, state);
@@ -529,7 +536,7 @@ spell_set_ui (EMComposerPrefs *prefs)
 	/* setup the language list */
 	if (!(lang = gconf_client_get_string (prefs->gconf, GNOME_SPELL_GCONF_DIR "/language", &err)) || err) {
 		g_free (lang);
-		g_error_free (err);
+		g_clear_error (&err);
 		lang = g_strdup (e_iconv_locale_language ());
 	}
 	
@@ -909,7 +916,7 @@ em_composer_prefs_construct (EMComposerPrefs *prefs)
 	
 	prefs->spell_able_button = glade_xml_get_widget (gui, "buttonSpellCheckEnable");
 	info_pixmap = glade_xml_get_widget (gui, "pixmapSpellInfo");
-	gtk_image_set_from_file (GTK_IMAGE (info_pixmap), EVOLUTION_IMAGES "/info-bulb.png");	
+	gtk_image_set_from_stock (GTK_IMAGE (info_pixmap), GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_BUTTON);
 	if (!spell_setup_check_options (prefs)) {
 		gtk_widget_hide (GTK_WIDGET (prefs->colour));
 		gtk_widget_hide (GTK_WIDGET (prefs->language));
